// Mock data structure
const mockData = {
  metrics: {
    'product-manager': [
      { title: 'Requirements Clarity Score', value: '92%', hint: 'Measures the clarity and completeness of requirements documentation based on peer reviews' },
      { title: 'Sprint Planning Accuracy', value: '87%', hint: 'Percentage of planned stories completed within sprint timeframe' },
      { title: 'Stakeholder Satisfaction', value: '4.5/5', hint: 'Average satisfaction score from stakeholder feedback surveys' }
    ],
    'java-dev': [
      { title: 'Code Coverage', value: '85%', hint: 'Percentage of code covered by automated tests' },
      { title: 'Build Success Rate', value: '98%', hint: 'Percentage of successful builds in CI/CD pipeline' },
      { title: 'Code Review Response Time', value: '4h', hint: 'Average time to first response on pull requests' }
    ],
    'frontend-dev': [
      { title: 'UI Test Coverage', value: '78%', hint: 'Percentage of UI components covered by automated tests' },
      { title: 'Page Load Performance', value: '96%', hint: 'Average Lighthouse performance score' },
      { title: 'Bug Resolution Rate', value: '94%', hint: 'Percentage of bugs resolved within SLA' }
    ],
    'qa': [
      { title: 'Test Case Creation Rate', value: '45/sprint', hint: 'Number of new test cases created per sprint' },
      { title: 'Defect Detection Rate', value: '89%', hint: 'Percentage of defects found before production' },
      { title: 'Automation Coverage', value: '76%', hint: 'Percentage of test cases automated' }
    ]
  }
};

// Initialize the dashboard
document.addEventListener('DOMContentLoaded', () => {
  initializeMetrics();
  initializeRankings();
  initializeEvaluationForm();
  setupEventListeners();
});

function initializeMetrics() {
  const container = document.getElementById('metrics-container');
  const roleSelect = document.getElementById('role-select');
  
  function updateMetrics(role) {
    container.innerHTML = '';
    const metrics = role === 'all' ? 
      Object.values(mockData.metrics).flat() :
      mockData.metrics[role];
    
    metrics.forEach(metric => {
      const card = document.createElement('div');
      card.className = 'metric-card';
      card.innerHTML = `
        <h3 class="metric-title" title="${metric.hint}">${metric.title}</h3>
        <div class="metric-value">${metric.value}</div>
      `;
      container.appendChild(card);
    });
  }
  
  roleSelect.addEventListener('change', (e) => updateMetrics(e.target.value));
  updateMetrics('all');
}

function initializeRankings() {
  const rankingsBody = document.getElementById('rankings-body');
  const mockRankings = [
    { rank: 1, name: 'John Doe', role: 'Java Developer', score: 95 },
    { rank: 2, name: 'Jane Smith', role: 'Frontend Developer', score: 92 },
    { rank: 3, name: 'Mike Johnson', role: 'QA Engineer', score: 90 }
  ];
  
  mockRankings.forEach(ranking => {
    const row = document.createElement('tr');
    row.innerHTML = `
      <td>${ranking.rank}</td>
      <td>${ranking.name}</td>
      <td>${ranking.role}</td>
      <td>${ranking.score}</td>
      <td><button onclick="showDetails('${ranking.name}')">View</button></td>
    `;
    rankingsBody.appendChild(row);
  });
}

function initializeEvaluationForm() {
  const employeeSelect = document.getElementById('employee-select');
  const mockEmployees = [
    'John Doe',
    'Jane Smith',
    'Mike Johnson'
  ];
  
  mockEmployees.forEach(employee => {
    const option = document.createElement('option');
    option.value = employee;
    option.textContent = employee;
    employeeSelect.appendChild(option);
  });
  
  // Initialize range input displays
  document.querySelectorAll('input[type="range"]').forEach(input => {
    const display = input.nextElementSibling;
    display.textContent = input.value;
    input.addEventListener('input', (e) => {
      display.textContent = e.target.value;
    });
  });
}

function setupEventListeners() {
  const form = document.getElementById('evaluation-form');
  form.addEventListener('submit', (e) => {
    e.preventDefault();
    // Here you would normally save to SQLite
    alert('Evaluation submitted successfully!');
    form.reset();
  });
}

function showDetails(name) {
  alert(`Detailed metrics for ${name}`);
}
